# Shape Analysis
The functions used to calculate morphological parameters of the bacteria.
::: micromorph.bacteria.shape_analysis

## Utility Functions
Collection of utility functions used to calculate morphological parameters of the bacteria, mostly to do with binary 
image processing.

::: micromorph.bacteria.utilities
